@@ -28,7 +28,7 @@ static const char description[] =
     I18N_NOOP ("KGoldrunner is a game of action and puzzle solving");
 
 // The intention is to keep the KGoldrunner version number in line with KDE.
-static const char version[] = "4.7";
+static const char version[] = "4.9";
 
 static bool gameDataOK();
 static void addCredits (KAboutData & about);
@@ -51,9 +51,6 @@ int main (int argc, char **argv)
     KCmdLineArgs::init (argc, argv, &about);
 
     KApplication app;
-#ifndef KGOLDRUNNER_USE_OPENAL
-    qWarning() << "KGoldrunner needs to use OpenAL and SndFile for sound.  Without those libraries, sound is permanently turned off.  The use of Phonon does not give good results and is deprecated.";
-#endif
     // See if we are starting with session management.
     if (app.isSessionRestored()) {
         // New RESTORE (KGrController);
