@@ -3,7 +3,7 @@
  *   Copyright 1997   Mario Weilguni <mweilguni@sime.com>                  *
  *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
  *   Copyright 2007  Mauricio Piacentini <mauricio@tabuleiro.com>          *
- *   Copyright 2009-2011  Frederik Schwarzer <schwarzerf@gmail.com>        *
+ *   Copyright 2009-2012  Frederik Schwarzer <schwarzer@kde.org>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,8 +31,6 @@
 #include <QPainter>
 #include <QTimer>
 
-#include <phonon/audiooutput.h>
-
 #include <cstring>
 
 
@@ -76,8 +74,10 @@ Board::Board(QWidget *parent)
       m_delay(0), m_level(0), m_shuffle(0),
       m_gameState(Normal), m_cheat(false),
       m_gravityFlag(true), m_solvableFlag(false), m_chineseStyleFlag(false), m_tilesCanSlideFlag(false),
-      m_highlightedTile(-1), m_connectionTimeout(0),
-      m_paintConnection(false), m_paintPossibleMoves(false), m_paintInProgress(false), m_media(0)
+      m_highlightedTile(-1),
+      m_paintConnection(false), m_paintPossibleMoves(false), m_paintInProgress(false),
+      m_soundPick(KStandardDirs::locate("sound", "kshisen/tile-touch.ogg")),
+      m_soundFall(KStandardDirs::locate("sound", "kshisen/tile-fall-tile.ogg"))
 {
     m_tileRemove1.first = -1;
 
@@ -227,7 +227,7 @@ void Board::gravity(bool update)
         }
     }
     if (Prefs::sounds() && fallingTiles) {
-        playSound(KStandardDirs::locate("sound", "kshisen/tile-fall-tile.ogg"));
+        m_soundFall.start();
     }
 }
 
@@ -708,7 +708,7 @@ void Board::paintEvent(QPaintEvent *e)
             ++pt1;
             ++pt2;
         }
-        QTimer::singleShot(m_connectionTimeout, this, SLOT(undrawConnection()));
+        QTimer::singleShot(delay(), this, SLOT(undrawConnection()));
         m_paintConnection = false;
     }
     if (m_paintPossibleMoves) {
@@ -859,7 +859,7 @@ void Board::performMove(PossibleMove &possibleMoves)
         madeMove(m_markX, m_markY, possibleMoves.m_path.last().x, possibleMoves.m_path.last().y);
     }
     drawPossibleMoves(false);
-    drawConnection(delay());
+    drawConnection();
     m_tileRemove1 = QPair<int, int>(m_markX, m_markY);
     m_tileRemove2 = QPair<int, int>(possibleMoves.m_path.last().x, possibleMoves.m_path.last().y);
     m_markX = -1;
@@ -942,7 +942,7 @@ void Board::marked(int x, int y)
     undrawConnection(); // is this still needed? (schwarzer)
 
     if (Prefs::sounds()) {
-        playSound(KStandardDirs::locate("sound", "kshisen/tile-touch.ogg"));
+        m_soundPick.start();
     }
 
     if (x == m_markX && y == m_markY) { // the piece is already marked
@@ -977,7 +977,7 @@ void Board::marked(int x, int y)
     // both tiles do not match
     if (!tilesMatch(tile1, tile2)) {
         unmarkTile();
-        emit tilesDontMatch();
+        emit tilesDoNotMatch();
         return;
     }
 
@@ -1332,7 +1332,7 @@ void Board::drawPossibleMoves(bool b)
     update();
 }
 
-void Board::drawConnection(int timeout)
+void Board::drawConnection()
 {
     m_paintInProgress = true;
     if (m_connection.isEmpty()) {
@@ -1347,7 +1347,6 @@ void Board::drawConnection(int timeout)
     updateField(x1, y1);
     updateField(x2, y2);
 
-    m_connectionTimeout = timeout;
     m_paintConnection = true;
     update();
 }
@@ -1713,7 +1712,7 @@ void Board::showHint()
 
     if (hint_I(m_possibleMoves)) {
         m_connection = m_possibleMoves.first().m_path;
-        drawConnection(1000);
+        drawConnection();
     }
 }
 
@@ -2017,24 +2016,10 @@ bool Board::hasCheated() const
 
 void Board::setSoundsEnabled(bool enabled)
 {
-    if (enabled) {
-        m_media = new Phonon::MediaObject(this);
-        Phonon::AudioOutput *audioOutput = new Phonon::AudioOutput(Phonon::GameCategory, this);
-        Phonon::createPath(m_media, audioOutput);
-    } else {
-        delete m_media;
-        m_media = 0;
-    }
     Prefs::setSounds(enabled);
     Prefs::self()->writeConfig();
 }
 
-void Board::playSound(const QString &sound)
-{
-    m_media->setCurrentSource(sound);
-    m_media->play();
-}
-
 #include "board.moc"
 
 // vim: expandtab:tabstop=4:shiftwidth=4
